@@ -1,7 +1,8 @@
+
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2009-2014 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -27,19 +28,21 @@
 #include "cmd.h"
 #include "prefs_lokalize.h"
 
-#include <klocale.h>
-#include <kdebug.h>
-#include <ktextedit.h>
-#include <ktextbrowser.h>
-#include <kcombobox.h>
-#include <kpushbutton.h>
+#include <klocalizedstring.h>
 
+#include <QDebug>
+#include <QStringBuilder>
 #include <QBoxLayout>
 #include <QStackedLayout>
 #include <QLabel>
-#include <QStringListModel>
 #include <QLineEdit>
+#include <QPushButton>
+#include <QTextBrowser>
+#include <QDialogButtonBox>
+#include <QComboBox>
+#include <QCompleter>
 #include <QKeyEvent>
+#include <QStringListModel>
 
 void TextEdit::keyPressEvent(QKeyEvent* keyEvent)
 {
@@ -54,17 +57,17 @@ void TextEdit::keyPressEvent(QKeyEvent* keyEvent)
 
 NoteEditor::NoteEditor(QWidget* parent)
  : QWidget(parent)
- , m_from(new KComboBox(this))
+ , m_from(new QComboBox(this))
  , m_fromLabel(new QLabel(i18nc("@info:label","From:"),this))
  , m_authors(new QStringListModel(this)) 
  , m_edit(new TextEdit(this))
+ , m_idx(-1)
 {
     setToolTip(i18nc("@info:tooltip","Save empty note to remove it"));
     m_from->setToolTip(i18nc("@info:tooltip","Author of this note"));
     m_from->setEditable(true);
     m_from->setModel(m_authors);
-    m_from->setAutoCompletion(true);
-    m_from->completionObject(true);
+    m_from->completer()->setModel(m_authors);
 
     QVBoxLayout* main=new QVBoxLayout(this);
     QHBoxLayout* prop=new QHBoxLayout;
@@ -73,21 +76,16 @@ NoteEditor::NoteEditor(QWidget* parent)
     prop->addWidget(m_from,42);
     main->addWidget(m_edit);
 
-    KPushButton* ok=new KPushButton(KStandardGuiItem::save(), this);
-    KPushButton* cancel=new KPushButton(KStandardGuiItem::discard(), this);
-    ok->setToolTip(i18n("Ctrl+Enter"));
-    cancel->setToolTip(i18n("Esc"));
+    QDialogButtonBox* box=new QDialogButtonBox(QDialogButtonBox::Save|QDialogButtonBox::Discard, this);
+    box->button(QDialogButtonBox::Save)->setToolTip(i18n("Ctrl+Enter"));
+    box->button(QDialogButtonBox::Discard)->setToolTip(i18n("Esc"));
 
     connect(m_edit,SIGNAL(accepted()),this,SIGNAL(accepted()));
     connect(m_edit,SIGNAL(rejected()),this,SIGNAL(rejected()));
-    connect(ok,SIGNAL(clicked()),this,SIGNAL(accepted()));
-    connect(cancel,SIGNAL(clicked()),this,SIGNAL(rejected()));
+    connect(box->button(QDialogButtonBox::Save),SIGNAL(clicked()),this,SIGNAL(accepted()));
+    connect(box->button(QDialogButtonBox::Discard),SIGNAL(clicked()),this,SIGNAL(rejected()));
 
-    QHBoxLayout* btns=new QHBoxLayout;
-    main->addLayout(btns);
-    btns->addStretch(42);
-    btns->addWidget(ok);
-    btns->addWidget(cancel);
+    main->addWidget(box);
 }
 
 void NoteEditor::setFromFieldVisible(bool v)
@@ -109,7 +107,13 @@ void NoteEditor::setNote(const Note& note, int idx)
     m_edit->setPlainText(note.content);
     QString from=note.from;
     if (from.isEmpty()) from=Settings::authorName();
-    m_from->setCurrentItem(from,/*insert*/true);
+    m_from->setCurrentText(from);
+    QStringList l=m_authors->stringList();
+    if (!l.contains(from))
+    {
+        l.append(from);
+        m_authors->setStringList(l);
+    }
     m_idx=idx;
     m_edit->setFocus();
 }
@@ -117,41 +121,39 @@ void NoteEditor::setNote(const Note& note, int idx)
 void NoteEditor::setNoteAuthors(const QStringList& authors)
 {
     m_authors->setStringList(authors);
-    m_from->completionObject()->insertItems(authors);
 }
 
-
-int displayNotes(KTextBrowser* browser, const QVector<Note>& notes, int active, bool multiple)
+int displayNotes(QTextBrowser* browser, const QVector< Note >& notes, int active, bool multiple)
 {
     QTextCursor t=browser->textCursor();
     t.movePosition(QTextCursor::End);
     int realOffset=0;
 
+    static const QString BR=QStringLiteral("<br />");
     if (!notes.isEmpty())
     {
-        t.insertHtml(i18nc("@info XLIFF notes representation","<b>Notes:</b>")+"<br />");
+        t.insertHtml(i18nc("@info XLIFF notes representation","<b>Notes:</b>")+BR);
         int i=0;
         foreach(const Note& note, notes)
         {
             if (!note.from.isEmpty())
-                t.insertHtml("<i>"+note.from+":</i> ");
+                t.insertHtml(QStringLiteral("<i>")%note.from%QStringLiteral(":</i> "));
 
             if (i==active)
                 realOffset=t.position();
-            QString content=Qt::escape(note.content);
+            QString content=escapeWithLinks(note.content);
             if (!multiple && content.contains('\n')) content+='\n';
-            content.replace('\n',"<br />");
-            content+=QString(" (<a href=\"note:/%1\">").arg(i)+i18nc("link to edit note","edit...")+"</a>)<br />";
+            content.replace('\n',BR);
+            content+=QString(QStringLiteral(" (<a href=\"note:/%1\">")).arg(i)%i18nc("link to edit note","edit...")%QStringLiteral("</a>)<br />");
             t.insertHtml(content);
             i++;
         }
         if (multiple)
-            t.insertHtml("<a href=\"note:/add\">"+i18nc("link to add a note","Add...")+"</a> ");
+            t.insertHtml(QStringLiteral("<a href=\"note:/add\">")%i18nc("link to add a note","Add...")%QStringLiteral("</a> "));
     }
     else
-        browser->insertHtml("<a href=\"note:/add\">"+i18nc("link to add a note","Add a note...")+"</a> ");
+        browser->insertHtml(QStringLiteral("<a href=\"note:/add\">")%i18nc("link to add a note","Add a note...")%QStringLiteral("</a> "));
 
     return realOffset;
 }
 
-#include "noteeditor.moc"
